-----------------------------------------------------------------------------------------------
-- Client Lua Script for ListDyes
-- Made by Smokeskin.
-- UI by SpeedHighway
-----------------------------------------------------------------------------------------------

require "Apollo"
require "GameLib"
require "Window"


-----------------------------------------------------------------------------------------------
-- ListDyes Module Definition
-----------------------------------------------------------------------------------------------
local ListDyes = {}


-----------------------------------------------------------------------------------------------
-- ListDyes Initialization
-----------------------------------------------------------------------------------------------

function ListDyes:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self

    return o
end

function ListDyes:Init()
    Apollo.RegisterAddon(self)
end


-----------------------------------------------------------------------------------------------
-- ListDyes OnLoad
-----------------------------------------------------------------------------------------------

function ListDyes:OnLoad()
	self.xmlDoc = XmlDoc.CreateFromFile("ListDyes.xml")
	self.xmlDoc:RegisterCallback("OnDocumentReady", self)	

end

function ListDyes:OnDocumentReady()
	if not self.xmlDoc then
		return
	end
	Apollo.RegisterEventHandler("DyeLearned", "OnDyeLearned", self)
	
	self.wndMain 	= Apollo.LoadForm(self.xmlDoc, "CharacterWindow", nil, self)	
	self.wndDyeList = self.wndMain:FindChild("DyeListContainer:DyeList")
	self.DyeText = self.wndMain:FindChild("DyeLabel:DyeText")
	
	Apollo.RegisterSlashCommand("ld", "ListDyes", self)
	Apollo.RegisterSlashCommand("listdyes", "ListDyes", self)
	
	self.wndMain:Show(false, true)
end


-----------------------------------------------------------------------------------------------
-- List Dyes
-----------------------------------------------------------------------------------------------

function ListDyes:ListDyes(cmd, sr)
	self:FillDyes()
--	self.DyeText:SetText("No Dye Selected")
	self.wndMain:Show(true)
	--local dyes = GameLib.GetKnownDyes()
--	table.sort(dyes, function(a,b) return a.strName < b.strName end)
--	
--
--	for _, dye in pairs(dyes) do
-- 		Print(dye.strName)
--	end
end

function ListDyes:OnClose()

	self.wndMain:Show(false)
end


---------------------------------------------------------------------------------------------------
-- Form Functions
---------------------------------------------------------------------------------------------------
--[[
function ListDyes:OnDyeSelect( wndHandler, wndControl, eMouseButton )
	if wndHandler ~= wndControl then return end
	
	local dyeName = wndControl:GetData().strName
	self.DyeText:SetText(dyeName)
end
]]--
function ListDyes:OnDyeLearned()
	self:FillDyes()
end

function ListDyes:FillDyes()
	self.wndDyeList:DestroyChildren()

	local tDyeSort = GameLib.GetKnownDyes()
	
	table.sort(tDyeSort, function (a,b) return a.strName < b.strName end)

	for idx, tDyeInfo in ipairs(tDyeSort) do
		local wndNewDye = Apollo.LoadForm(self.xmlDoc, "DyeColor", self.wndDyeList, self)
		if wndNewDye == nil then
			Print("Was unable to create new dye")
		end
		local strName = ""

		if tDyeInfo.strName and tDyeInfo.strName:len() > 0 then
			strName = tDyeInfo.strName
		else
			strName = String_GetWeaselString(Apollo.GetString("CRB_CurlyBrackets"), "", tDyeInfo.nRampIndex)
		end

		local strSprite = "CRB_DyeRampSprites:sprDyeRamp_" .. tDyeInfo.nRampIndex
		wndNewDye:FindChild("DyeSwatchArtHack:DyeSwatch"):SetSprite(strSprite)
		wndNewDye:FindChild("DyeName"):SetText(strName)
		
		--wndNewDye:SetTooltip(strName)

		local tNewDyeInfo = {}
		tNewDyeInfo.id = tDyeInfo.nId
		tNewDyeInfo.strName = strName
		tNewDyeInfo.strSprite = strSprite
		
		wndNewDye:SetData(tNewDyeInfo)
	end
	
	self.wndDyeList:ArrangeChildrenTiles()
end

-----------------------------------------------------------------------------------------------
-- ListDyes Instance
-----------------------------------------------------------------------------------------------
local ListDyesInst = ListDyes:new()
ListDyesInst:Init()
